@@ -1,11 +1,9 @@
 #
 # Copyright (c) nexB Inc. and others.
-# Visit https://github.com/nexB/typecode/
-# Visit https://nexb.com https://aboutcode.org and
-#  https://github.com/nexB/scancode-toolkit/ for support
-# ScanCode is a trademark of nexB Inc.
+# SPDX-License-Identifier: Apache-2.0
 #
-# SPDX-License_identifier: Apache-2.0
+# Visit https://aboutcode.org and https://github.com/nexB/ for support and download.
+# ScanCode is a trademark of nexB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,8 +21,6 @@
 import contextlib
 import io
 import os
-import fnmatch
-import mimetypes as mimetype_python
 
 import attr
 from binaryornot.helpers import get_starting_chunk
@@ -45,6 +41,7 @@ from commoncode import text
 from typecode import entropy
 from typecode import extractible
 from typecode import magic2
+from typecode import mimetypes
 from typecode.pygments_lexers import ClassNotFound as LexerClassNotFound
 from typecode.pygments_lexers import get_lexer_for_filename
 from typecode.pygments_lexers import guess_lexer
@@ -52,6 +49,18 @@ from typecode.pygments_lexers import guess_lexer
 """
 Utilities to detect and report the type of a file or path based on its name,
 extension and mostly its content.
+
+
+TODO: consider adding support for these
+
+https://www.freedesktop.org/wiki/Specifications/shared-mime-info-spec/
+ https://github.com/freedesktop/xdg-shared-mime-info
+ https://pypi.python.org/pypi/z3c.sharedmimeinfo/0.1.0
+ https://github.com/chesstrian/mimetype-description
+
+and :
+ https://github.com/mime-types/mime-types-data
+
 """
 
 # Tracing flag
@@ -73,13 +82,6 @@ if TRACE:
     def logger_debug(*args):
         return logger.debug(' '.join(isinstance(a, str) and a or repr(a) for a in args))
 
-data_dir = os.path.join(os.path.dirname(__file__), 'data')
-
-# Python mimetypes path setup using Apache mimetypes DB
-os.environ['XDG_DATA_DIRS'] = os.path.join(data_dir, 'apache')
-os.environ['XDG_DATA_HOME'] = os.environ['XDG_DATA_DIRS']
-APACHE_MIME_TYPES = os.path.join(data_dir, 'apache', 'mime.types')
-
 # Ensure that all dates are UTC, especially for fine free file.
 os.environ['TZ'] = 'UTC'
 
@@ -105,14 +107,9 @@ MAKEFILE_EXTENSIONS = (
     'Makefile.inc',
 )
 
-# TODO:
-# http://svn.zope.org/z3c.mimetype/trunk/?pathrev=103648
-# http://svn.zope.org/z3c.sharedmimeinfo/trunk/TODO.txt?revision=103668&view=markup
-# https://pypi.python.org/pypi/z3c.sharedmimeinfo/0.1.0
-# https://github.com/plone/Products.MimetypesRegistry/
 
 # Global registry of Type objects, keyed by location
-# FIXME: can this be a memroy hog for very large scans?
+# FIXME: can this be a memory hog for very large scans?
 _registry = {}
 
 
@@ -133,7 +130,7 @@ def get_type(location):
 
 class Type(object):
     """
-    Content, media and mime type information about a file.
+    Content, media and mimetype information about a file.
     All flags and values are tri-booleans. You can test a value state with
     `is`:
 
@@ -261,8 +258,12 @@ class Type(object):
 
     def __repr__(self):
         return ('Type(ftf=%r, mtf=%r, ftpyg=%r, mtpy=%r)'
-                % (self.filetype_file, self.mimetype_file,
-                   self.filetype_pygment, self.mimetype_python))
+            % (
+                self.filetype_file,
+                self.mimetype_file,
+                self.filetype_pygment,
+                self.mimetype_python
+        ))
 
     def to_dict(self, include_date=True):
         """
@@ -299,21 +300,12 @@ class Type(object):
     @property
     def mimetype_python(self):
         """
-        Return the mimetype using the Python stdlib and the Apache HTTPD
-        mimetype definitions.
+        Return the mimetype using the a map of mimetypes by file extension.
         """
         if self._mimetype_python is None:
             self._mimetype_python = ''
             if self.is_file is True:
-                if not mimetype_python.inited:
-                    # Ad workaround for this Python bug
-                    # https://bugs.python.org/issue4963?#msg384730
-                    # and https://github.com/nexB/typecode/issues/14
-                    # ... we monkey mimetypes.knownfiles to avoid problems
-                    mimetype_python.knownfiles = []
-                    mimetype_python.init([APACHE_MIME_TYPES])
-                val = mimetype_python.guess_type(self.location)[0]
-                self._mimetype_python = val or ''
+                self._mimetype_python = mimetypes.guess_type(self.location) or ''
         return self._mimetype_python
 
     @property
@@ -353,6 +345,14 @@ class Type(object):
                     self._filetype_pygment = ''
         return self._filetype_pygment
 
+    @property
+    def file_name(self):
+        """
+        Return the file name for this location.
+        """
+        # TODO: cache me
+        return fileutils.file_name(self.location)
+
     # FIXME: we way we use tri booleans is a tad ugly
 
     @property
@@ -731,10 +731,7 @@ class Type(object):
             '.s', '.asm', '.hpp', '.hxx', '.h++', '.i', '.ii', '.m'])
 
         ext = fileutils.file_extension(self.location)
-        if self.is_text is True and ext.lower() in C_EXTENSIONS:
-            return True
-        else:
-            return False
+        return self.is_text is True and ext.lower() in C_EXTENSIONS
 
     @property
     def is_winexe(self):
@@ -742,10 +739,7 @@ class Type(object):
         Return True if a the file is a windows executable.
         """
         ft = self.filetype_file.lower()
-        if 'for ms windows' in ft or ft.startswith('pe32'):
-            return True
-        else:
-            return False
+        return 'for ms windows' in ft or ft.startswith('pe32')
 
     @property
     def is_elf(self):
@@ -773,10 +767,7 @@ class Type(object):
     @property
     def is_stripped_elf(self):
         if self.is_elf is True:
-            if 'not stripped' not in self.filetype_file.lower():
-                return True
-            else:
-                return False
+            return 'not stripped' not in self.filetype_file.lower()
         else:
             return False
 
@@ -785,32 +776,14 @@ class Type(object):
         """
         FIXME: Check the filetype.
         """
-        if self.is_file is True:
-            name = fileutils.file_name(self.location)
-
-            if (fnmatch.fnmatch(name, '*.java')
-             or fnmatch.fnmatch(name, '*.aj')
-             or fnmatch.fnmatch(name, '*.jad')
-             or fnmatch.fnmatch(name, '*.ajt')):
-                return True
-            else:
-                return False
-        else:
-            return False
+        return self.is_file and self.file_name.lower().endswith(('.java', '.aj', '.jad', '.ajt'))
 
     @property
     def is_java_class(self):
         """
         FIXME: Check the filetype.
         """
-        if self.is_file is True:
-            name = fileutils.file_name(self.location)
-            if fnmatch.fnmatch(name, '*?.class'):
-                return True
-            else:
-                return False
-        else:
-            return False
+        return self.is_file and self.file_name.lower().endswith('.class')
 
 
 @attr.attributes
